Module extendr_api::robj [−][src]
R object handling.
See. https://cran.r-project.org/doc/manuals/R-exts.html
Fundamental principals:
- Any function that can break the protection mechanism is unsafe.
- Users should be able to do almost everything without using libR_sys.
- The interface should be friendly to R users without Rust experience.
Re-exports
pub use iter::*; |
Enums
| Robj | Wrapper for an R S-expression pointer (SEXP). |
Traits
| AsTypedSlice | Generic access to typed slices in an Robj. |
| FromRobj | Trait used for incomming parameter conversion. |
| IntoRobj | |
| RobjItertools | Extensions to iterators for R objects including RobjItertools::collect_robj(). |
| ToVectorValue |
|