Module thread_safety

Module thread_safety 

Provide limited protection for multithreaded access to the R API.

Functions

catch_r_error
Wrap an R function such as Rf_findFunction and convert errors and panics into results.
register_extendr_panic_hook
This function registers a configurable print panic hook, for use in extendr-based R-packages. If the environment variable EXTENDR_BACKTRACE is set to either true or 1, then it displays the entire Rust panic traceback (default hook), otherwise it omits the panic backtrace.
single_threaded
Run f while ensuring that f runs in a single-threaded manner.
throw_r_error