Provide limited protection for multithreaded access to the R API.
Functions
- catch_
r_ error - Wrap an R function such as
Rf_findFunctionand convert errors and panics into results. - register_
extendr_ panic_ hook - This function registers a configurable print panic hook, for use in extendr-based R-packages.
If the environment variable
EXTENDR_BACKTRACEis set to eithertrueor1, then it displays the entire Rust panic traceback (default hook), otherwise it omits the panic backtrace. - single_
threaded - Run
fwhile ensuring thatfruns in a single-threaded manner. - throw_
r_ error